numberOfVisibleChild method
Gets the number of visible children of the ListTreeView
Implementation
int numberOfVisibleChild() {
return this.rootController.numberOfVisibleDescendants();
}
Gets the number of visible children of the ListTreeView
int numberOfVisibleChild() {
return this.rootController.numberOfVisibleDescendants();
}